package new_mobile_api_controllers

import (
	"XT_New/controllers/mobile_api_controllers"
	"XT_New/enums"
	"XT_New/service"
	"XT_New/utils"
	"fmt"
	"time"
)

type NewCommonApiController struct {
	mobile_api_controllers.MobileBaseAPIAuthController
}

func (this *NewCommonApiController) GetTotalDialysis() {
	timeLayout := "2006-01-02"
	loc, _ := time.LoadLocation("Local")
	startime := this.GetString("startime")

	endtime := this.GetString("endtime")

	startTimes, _ := time.ParseInLocation(timeLayout+" 15:04:05", startime+" 00:00:00", loc)
	startimes := startTimes.Unix()

	endtimes, _ := time.ParseInLocation(timeLayout+" 15:04:05", endtime+" 00:00:00", loc)
	endtimeData := endtimes.Unix()

	adminUser := this.GetMobileAdminUserInfo()
	orgid := adminUser.Org.Id

	//统计透析总量
	_, total, _ := service.GetDialysiTotal(startimes, endtimeData, orgid)

	modeType, err := service.GetDialysisCountMode(startimes, endtimeData, orgid)
	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}
	this.ServeSuccessJSON(map[string]interface{}{
		"total":    total,
		"modetype": modeType,
	})
}

func (this *NewCommonApiController) GetMobileTotalLapseCount() {
	startime, _ := this.GetInt64("startime")

	endtime, _ := this.GetInt64("endtime")

	adminUser := this.GetMobileAdminUserInfo()
	orgid := adminUser.Org.Id
	//统计转出的病人
	patient, err := service.GetTotalRollOutPatients(orgid, startime, endtime)
	patienttwo, err := service.GetTotalRollOutPatientsTwo(orgid, startime, endtime)
	count := service.GetPatientTotalCount(orgid)
	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}
	this.ServeSuccessJSON(map[string]interface{}{
		"patient":    patient,
		"count":      count,
		"patienttwo": patienttwo,
	})
}

func (this *NewCommonApiController) GetMobileTotalSexCount() {
	//startime, _ := this.GetInt64("startime")
	//fmt.Println("startime", startime)
	//endtime, _ := this.GetInt64("endtime")
	//fmt.Println("endtime", endtime)
	adminUser := this.GetMobileAdminUserInfo()
	orgid := adminUser.Org.Id
	total := service.GetPatientTotalCount(orgid)
	_, totalSex, err := service.GetManPatientTotal(orgid)
	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}
	this.ServeSuccessJSON(map[string]interface{}{
		"total":    total,
		"totalSex": totalSex,
	})
}

func (this *NewCommonApiController) GetMobileTotalInfectiousCout() {
	startime, _ := this.GetInt64("startime")

	endtime, _ := this.GetInt64("endtime")

	adminUser := this.GetMobileAdminUserInfo()
	orgid := adminUser.Org.Id
	//统计透析总人数
	total := service.GetPatientTotalCount(orgid)
	//统计透析人数传染病所占比例
	count, err := service.GetPatientInfectiousCount(orgid, startime, endtime)
	//统计其他
	_, otherTotal, err := service.GetPatientOtherInfectious(orgid)
	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}
	this.ServeSuccessJSON(map[string]interface{}{
		"total":      total,
		"count":      count,
		"otherTotal": otherTotal,
	})
}

func (this *NewCommonApiController) GetMobileTotalAgeCount() {
	//startime, _ := this.GetInt64("startime")
	//
	//endtime, _ := this.GetInt64("endtime")

	adminUser := this.GetMobileAdminUserInfo()
	orgid := adminUser.Org.Id
	total := service.GetPatientTotalCount(orgid)
	agecount, err := service.GetTotalAgeCount(orgid)
	//two, err := service.GetTotalAgeCountTwo(orgid, startime, endtime)
	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}
	this.ServeSuccessJSON(map[string]interface{}{
		"total":    total,
		"ageCount": agecount,
	})
}

func (this *NewCommonApiController) GetMobileTotalDialysisCount() {
	//startime, _ := this.GetInt64("startime")
	//
	//endtime, _ := this.GetInt64("endtime")

	adminUser := this.GetMobileAdminUserInfo()
	orgid := adminUser.Org.Id
	recordDateStr := time.Now().Format("2006-01-02")
	recordDate, parseDateErr := utils.ParseTimeStringToTime("2006-01-02", recordDateStr)
	fmt.Println(parseDateErr)
	nowtime := recordDate.Unix()
	//统计透析总人数
	total := service.GetPatientTotalCount(orgid)
	//获取该机构下的所有病人数据
	ageData, err := service.GetDialysisAgeData(orgid)

	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}
	this.ServeSuccessJSON(map[string]interface{}{
		"total":   total,
		"ageData": ageData,
		"nowtime": nowtime,
	})
}

func (this *NewCommonApiController) GetMobilePatientList() {
	adminUser := this.GetMobileAdminUserInfo()
	orgid := adminUser.Org.Id
	patients, err := service.GetCurentOrgPatients(orgid)
	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}
	this.ServeSuccessJSON(map[string]interface{}{
		"patients": patients,
	})
}

func (this *NewCommonApiController) GetPrescriptionlist() {

	startime := this.GetString("startime")

	endtime := this.GetString("endtime")

	startDate, parseDateErr := utils.ParseTimeStringToTime("2006-01-02", startime)
	fmt.Println("parseDateErr", parseDateErr)
	statime := startDate.Unix()

	//endDate, _ := utils.ParseTimeStringToTime("2006-01-02", endtime)
	//
	//entime := endDate.Unix()
	endtimeStr := endtime + " 23:59:59"
	endtimeStrs, _ := utils.ParseTimeStringToTime("2006-01-02 15:04:05", endtimeStr)
	entime := endtimeStrs.Unix()

	page, _ := this.GetInt64("page")

	limit, _ := this.GetInt64("limit")

	adminInfo := this.GetMobileAdminUserInfo()
	orgId := adminInfo.Org.Id
	count, _ := service.TotalDialysisCount(statime, entime, orgId)
	prescriptionList, _ := service.GetAllDialysisList(statime, entime, orgId)
	list, totallist, err := service.GetDialysisPatientList(statime, entime, page, limit, orgId)
	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}
	this.ServeSuccessJSON(map[string]interface{}{
		"list":             list,
		"totallist":        totallist,
		"prescriptionList": prescriptionList,
		"count":            count,
	})
}

func (this *NewCommonApiController) GetMobilePatientDetail() {
	adminUser := this.GetMobileAdminUserInfo()
	orgId := adminUser.Org.Id
	id, _ := this.GetInt64("id")

	startime := this.GetString("startime")

	endtime := this.GetString("endtime")
	startDate, parseDateErr := utils.ParseTimeStringToTime("2006-01-02", startime)
	fmt.Println("parseDateErr", parseDateErr)
	statime := startDate.Unix()

	endDate, _ := utils.ParseTimeStringToTime("2006-01-02", endtime)

	entime := endDate.Unix()

	fmt.Println(endtime)
	limit, _ := this.GetInt64("limit")

	page, _ := this.GetInt64("page")

	patients, total, err := service.GetDialysisDetailById(id, orgId, statime, entime, limit, page)
	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}
	this.ServeSuccessJSON(map[string]interface{}{
		"patients": patients,
		"total":    total,
	})
}

func (this *NewCommonApiController) ToSearchPatient() {
	adminUser := this.GetMobileAdminUserInfo()
	orgId := adminUser.Org.Id
	//keyword := this.GetString("keyword")
	patientid, _ := this.GetInt64("patientid")
	startime := this.GetString("startime")

	endtime := this.GetString("endtime")
	startDate, parseDateErr := utils.ParseTimeStringToTime("2006-01-02", startime)
	fmt.Println("parseDateErr", parseDateErr)
	statime := startDate.Unix()

	endDate, _ := utils.ParseTimeStringToTime("2006-01-02", endtime)

	entime := endDate.Unix()

	limit, _ := this.GetInt64("limit")

	page, _ := this.GetInt64("page")

	patient, total, err := service.GetPrescritionByName(orgId, patientid, statime, entime, limit, page)

	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}
	this.ServeSuccessJSON(map[string]interface{}{
		"patient": patient,
		"total":   total,
	})
}

func (this *NewCommonApiController) GetAllPatientsMode() {
	adminUser := this.GetMobileAdminUserInfo()
	orgId := adminUser.Org.Id
	startime := this.GetString("startime")

	endtime := this.GetString("endtime")
	startDate, parseDateErr := utils.ParseTimeStringToTime("2006-01-02", startime)
	fmt.Println("parseDateErr", parseDateErr)
	statime := startDate.Unix()

	endDate, _ := utils.ParseTimeStringToTime("2006-01-02", endtime)
	entime := endDate.Unix()

	value, _ := this.GetInt64("value")

	limit, _ := this.GetInt64("limit")

	page, _ := this.GetInt64("page")

	modeId, _ := this.GetInt64("mode_id")

	treatinfo, total, err := service.GetTreateInfo(orgId, statime, entime, value, limit, page)
	statistics, ttd, err := service.GetStatistics(orgId, statime, entime, modeId)
	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}
	this.ServeSuccessJSON(map[string]interface{}{
		"statistics": statistics,
		"ttd":        ttd,
		"total":      total,
		"treatinfo":  treatinfo,
	})
}

func (this *NewCommonApiController) GetMobileInspectionList() {
	adminUser := this.GetMobileAdminUserInfo()
	orgid := adminUser.Org.Id
	startime := this.GetString("startime")

	endtime := this.GetString("endtime")
	startDate, parseDateErr := utils.ParseTimeStringToTime("2006-01-02", startime)
	fmt.Println("parseDateErr", parseDateErr)
	statime := startDate.Unix()

	secondQuarterEndStr := endtime + " 23:59:59"
	secondQuarterEnds, parseDateErr := utils.ParseTimeStringToTime("2006-01-02 15:04:05", secondQuarterEndStr)
	entime := secondQuarterEnds.Unix()

	patientid, _ := this.GetInt64("patientid")
	references, err := service.GetInspectionTotalCount(orgid)
	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}

	counts, err := service.GetInspectionProjectCount(orgid, statime, entime, patientid)

	this.ServeSuccessJSON(map[string]interface{}{
		"Inspection": references,
		"counts":     counts,
	})
}

func (this *NewCommonApiController) GetPatientInspectionDetail() {
	adminUser := this.GetMobileAdminUserInfo()
	orgId := adminUser.Org.Id
	id, _ := this.GetInt64("id")

	startime := this.GetString("startime")
	endtime := this.GetString("endtime")
	startDate, parseDateErr := utils.ParseTimeStringToTime("2006-01-02", startime)
	fmt.Println("parseDateErr", parseDateErr)
	statime := startDate.Unix()

	//endDate, _ := utils.ParseTimeStringToTime("2006-01-02", endtime)
	//entime := endDate.Unix()
	//fmt.Println("结束日期", entime)
	secondQuarterEndStr := endtime + " 23:59:59"
	secondQuarterEnds, parseDateErr := utils.ParseTimeStringToTime("2006-01-02 15:04:05", secondQuarterEndStr)
	entime := secondQuarterEnds.Unix()
	patientdetail, err := service.GetInspectionDetailById(id, orgId, statime, entime)
	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}
	this.ServeSuccessJSON(map[string]interface{}{
		"patientdetail": patientdetail,
	})
}

func (this *NewCommonApiController) GetSeachPatientDetail() {
	adminUser := this.GetMobileAdminUserInfo()
	orgId := adminUser.Org.Id
	//keyword := this.GetString("keyword")
	//fmt.Println("keyword", keyword)
	patientid, _ := this.GetInt64("patientid")
	startime := this.GetString("startime")
	endtime := this.GetString("endtime")
	startDate, parseDateErr := utils.ParseTimeStringToTime("2006-01-02", startime)
	fmt.Println("parseDateErr", parseDateErr)
	statime := startDate.Unix()

	//endDate, _ := utils.ParseTimeStringToTime("2006-01-02", endtime)
	//entime := endDate.Unix()
	//fmt.Println("结束日期", entime)
	secondQuarterEndStr := endtime + " 23:59:59"
	secondQuarterEnds, parseDateErr := utils.ParseTimeStringToTime("2006-01-02 15:04:05", secondQuarterEndStr)
	entime := secondQuarterEnds.Unix()
	PatientsInfo, err := service.GetSearchPatientInfo(orgId, patientid, statime, entime)
	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}
	this.ServeSuccessJSON(map[string]interface{}{
		"PatientsInfo": PatientsInfo,
	})
}

func (this *NewCommonApiController) GetMobileNormdata() {

	adminInfo := this.GetMobileAdminUserInfo()
	orgid := adminInfo.Org.Id
	//获取系统数据
	normdata, err := service.GetNormDataByOrgId(orgid)
	//if len(normdata) == 0 {
	//	normdata, err := service.GetNormData(0)
	//	if err != nil {
	//		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
	//		return
	//	}
	//	this.ServeSuccessJSON(map[string]interface{}{
	//		"normdata": normdata,
	//	})
	//}
	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}
	this.ServeSuccessJSON(map[string]interface{}{
		"normdata": normdata,
	})
}

func (this *NewCommonApiController) GetMobileProjectlsit() {

	adminInfo := this.GetMobileAdminUserInfo()
	orgid := adminInfo.Org.Id
	fmt.Println("orgid", orgid)
	lapseto, _ := this.GetInt64("lapseto")
	fmt.Println("专柜", lapseto)
	itemtype, _ := this.GetInt64("itemtype")
	fmt.Println("itemtype", itemtype)
	modetype, _ := this.GetInt64("modeltype")
	fmt.Println(modetype)

	firstQuarterStart := this.GetString("first_quarter_start")
	firstQuarterStartStr, _ := utils.ParseTimeStringToTime("2006-01-02", firstQuarterStart)
	firstQuarterStartUnix := firstQuarterStartStr.Unix()

	fisrtQuarterEnd := this.GetString("first_qurter_end")
	fisrtQuarterEndStr := fisrtQuarterEnd + " 23:59:59"
	fisrtQuarterEnds, _ := utils.ParseTimeStringToTime("2006-01-02 15:04:05", fisrtQuarterEndStr)
	fisrtQuarterEndStrUnix := fisrtQuarterEnds.Unix()

	secondeQuarterStart := this.GetString("second_qurter_start")
	secondeQuarterStartStr, _ := utils.ParseTimeStringToTime("2006-01-02", secondeQuarterStart)
	secondeQuarterStartUnix := secondeQuarterStartStr.Unix()

	secondQuarterEnd := this.GetString("second_qurter_end")
	secondQuarterEndStr := secondQuarterEnd + " 23:59:59"
	secondQuarterEnds, _ := utils.ParseTimeStringToTime("2006-01-02 15:04:05", secondQuarterEndStr)
	secondQuarterEndStrUnix := secondQuarterEnds.Unix()

	threeQuarterStart := this.GetString("three_qurter_start")
	threeQuarterStartStr, _ := utils.ParseTimeStringToTime("2006-01-02", threeQuarterStart)
	threeQuarterStartUnix := threeQuarterStartStr.Unix()

	threeQuarterEnd := this.GetString("three_qurter_end")
	threeQuarterEndStr := threeQuarterEnd + " 23:59:59"
	threeQuarterEnds, _ := utils.ParseTimeStringToTime("2006-01-02 15:04:05", threeQuarterEndStr)
	threeQuarterEndStrUnix := threeQuarterEnds.Unix()

	fourQuarterStart := this.GetString("four_qurter_start")
	fourQuarterStartStr, _ := utils.ParseTimeStringToTime("2006-01-02", fourQuarterStart)
	fourQuarterStartUnix := fourQuarterStartStr.Unix()

	fourQuarterEnd := this.GetString("four_qurter_end")
	fourQuarterEndStr := fourQuarterEnd + " 23:59:59"
	fourQuarterEnds, _ := utils.ParseTimeStringToTime("2006-01-02 15:04:05", fourQuarterEndStr)
	fourQuarterEndStrUnix := fourQuarterEnds.Unix()
	//fmt.Println("第四季度结束时间", fourQuarterEndStrUnix)
	rangetype, _ := this.GetInt64("range_type")
	//按季度统计
	if rangetype == 1 {
		//统计总共
		list, err := service.GetProjectList(orgid, lapseto, modetype, firstQuarterStartUnix, fourQuarterEndStrUnix, firstQuarterStartUnix, fisrtQuarterEndStrUnix, secondeQuarterStartUnix, secondQuarterEndStrUnix, threeQuarterStartUnix, threeQuarterEndStrUnix, fourQuarterStartUnix, fourQuarterEndStrUnix)
		//统计达标个数
		standList, err := service.GetProjectStandList(orgid, lapseto, modetype, firstQuarterStartUnix, fourQuarterEndStrUnix, firstQuarterStartUnix, fisrtQuarterEndStrUnix, secondeQuarterStartUnix, secondQuarterEndStrUnix, threeQuarterStartUnix, threeQuarterEndStrUnix, fourQuarterStartUnix, fourQuarterEndStrUnix)
		if err != nil {
			this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
			return
		}

		this.ServeSuccessJSON(map[string]interface{}{
			"list":      list,
			"standList": standList,
		})
		return
	}

	if rangetype == 2 {
		list, err := service.GetProjectListOne(orgid, lapseto, modetype, firstQuarterStartUnix, fourQuarterEndStrUnix, firstQuarterStartUnix, fisrtQuarterEndStrUnix, secondeQuarterStartUnix, secondQuarterEndStrUnix, threeQuarterStartUnix, threeQuarterEndStrUnix, fourQuarterStartUnix, fourQuarterEndStrUnix)
		//统计达标个数
		standList, err := service.GetProjectStandListOne(orgid, lapseto, modetype, firstQuarterStartUnix, fourQuarterEndStrUnix, firstQuarterStartUnix, fisrtQuarterEndStrUnix, secondeQuarterStartUnix, secondQuarterEndStrUnix, threeQuarterStartUnix, threeQuarterEndStrUnix, fourQuarterStartUnix, fourQuarterEndStrUnix)
		if err != nil {
			this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
			return
		}

		this.ServeSuccessJSON(map[string]interface{}{
			"list":      list,
			"standList": standList,
		})
		return
	}
}

func (this *NewCommonApiController) GetMobileFirstQuarter() {

	adminUser := this.GetMobileAdminUserInfo()
	orgid := adminUser.Org.Id
	lapseto, _ := this.GetInt64("lapseto")
	fmt.Println("转归", lapseto)
	startime := this.GetString("startime")

	startDate, parseDateErr := utils.ParseTimeStringToTime("2006-01-02", startime)
	fmt.Println("parseDateErr", parseDateErr)
	statime := startDate.Unix()

	endtime := this.GetString("endtime")

	endTimeYMDHmsStr := endtime + " 23:59:59"
	endDate, _ := utils.ParseTimeStringToTime("2006-01-02 15:04:05", endTimeYMDHmsStr)
	entime := endDate.Unix()

	count, err := service.GetQuarterTotalCount(orgid, statime, entime, lapseto)
	countwo, _ := service.GetQuarterTotalCountTwo(orgid, statime, entime, lapseto)
	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}
	this.ServeSuccessJSON(map[string]interface{}{
		"count":   count,
		"countwo": countwo,
	})
}

func (this *NewCommonApiController) GetMobileMonthProjectList() {
	adminInfo := this.GetMobileAdminUserInfo()
	orgid := adminInfo.Org.Id
	lapseto, _ := this.GetInt64("lapseto")

	itemtype, _ := this.GetInt64("itemtype")
	fmt.Println("itemtype", itemtype)
	modetype, _ := this.GetInt64("modeltype")

	januaryStart := this.GetString("januaryStart")

	januaryStartStr, _ := utils.ParseTimeStringToTime("2006-01-02", januaryStart)
	januaryStartStrUnix := januaryStartStr.Unix()

	januaryEnd := this.GetString("januaryEnd")

	januaryEndStr := januaryEnd + " 23:59:59"
	januaryEndStrs, _ := utils.ParseTimeStringToTime("2006-01-02 15:04:05", januaryEndStr)
	januaryEndStrUnix := januaryEndStrs.Unix()

	febStart := this.GetString("febStart")

	febStartStr, _ := utils.ParseTimeStringToTime("2006-01-02", febStart)
	febStartStrStrUnix := febStartStr.Unix()

	febEnd := this.GetString("febEnd")

	febEndStr := febEnd + " 23:59:59"
	febEndStrs, _ := utils.ParseTimeStringToTime("2006-01-02 15:04:05", febEndStr)
	febEndStrUnix := febEndStrs.Unix()

	marchStart := this.GetString("marchStart")

	marchStartStr, _ := utils.ParseTimeStringToTime("2006-01-02", marchStart)
	marchStartStrUnix := marchStartStr.Unix()

	marchEnd := this.GetString("marchEnd")

	marchEndStr := marchEnd + " 23:59:59"
	marchEndStrs, _ := utils.ParseTimeStringToTime("2006-01-02 15:04:05", marchEndStr)
	marchEndStrUnix := marchEndStrs.Unix()

	aprStart := this.GetString("aprStart")

	aprStartStr, _ := utils.ParseTimeStringToTime("2006-01-02", aprStart)
	aprStartStrUnix := aprStartStr.Unix()

	aprEnd := this.GetString("aprEnd")

	aprEndStr := aprEnd + " 23:59:59"
	aprEndStrs, _ := utils.ParseTimeStringToTime("2006-01-02 15:04:05", aprEndStr)
	aprEndStrsUnix := aprEndStrs.Unix()

	mayStart := this.GetString("mayStart")

	mayStartStr, _ := utils.ParseTimeStringToTime("2006-01-02", mayStart)
	mayStartStrUnix := mayStartStr.Unix()

	mayEnd := this.GetString("mayEnd")

	mayEndStr := mayEnd + " 23:59:59"
	mayEndStrs, _ := utils.ParseTimeStringToTime("2006-01-02 15:04:05", mayEndStr)
	mayEndStrsUnix := mayEndStrs.Unix()

	junStart := this.GetString("junStart")

	junStartStr, _ := utils.ParseTimeStringToTime("2006-01-02", junStart)
	junStartStrUnix := junStartStr.Unix()

	junEnd := this.GetString("junEnd")

	junEndStr := junEnd + " 23:59:59"
	junEndStrs, _ := utils.ParseTimeStringToTime("2006-01-02 15:04:05", junEndStr)
	junEndStrsUnix := junEndStrs.Unix()

	julStart := this.GetString("julStart")

	julStartStr, _ := utils.ParseTimeStringToTime("2006-01-02", julStart)
	julStartStrUnix := julStartStr.Unix()

	julEnd := this.GetString("julEnd")

	julEndStr := julEnd + " 23:59:59"
	julEndStrs, _ := utils.ParseTimeStringToTime("2006-01-02 15:04:05", julEndStr)
	julEndStrsUnix := julEndStrs.Unix()

	augStart := this.GetString("augStart")

	augStartStr, _ := utils.ParseTimeStringToTime("2006-01-02", augStart)
	augStartStrUnix := augStartStr.Unix()

	augEnd := this.GetString("augEnd")

	augEndStr := augEnd + " 23:59:59"
	augEndStrs, _ := utils.ParseTimeStringToTime("2006-01-02 15:04:05", augEndStr)
	augEndStrsUnix := augEndStrs.Unix()

	sepStart := this.GetString("sepStart")

	sepStartStr, _ := utils.ParseTimeStringToTime("2006-01-02", sepStart)
	sepStartStrUnix := sepStartStr.Unix()
	fmt.Println("九月使", sepStartStrUnix)
	sepEnd := this.GetString("sepEnd")

	sepEndStr := sepEnd + " 23:59:59"
	sepEndStrs, _ := utils.ParseTimeStringToTime("2006-01-02 15:04:05", sepEndStr)
	sepEndStrsUnix := sepEndStrs.Unix()

	octStart := this.GetString("octStart")

	octStartStr, _ := utils.ParseTimeStringToTime("2006-01-02", octStart)
	octStartStrUnix := octStartStr.Unix()

	octEnd := this.GetString("octEnd")

	octEndStr := octEnd + " 23:59:59"
	octEndStrs, _ := utils.ParseTimeStringToTime("2006-01-02 15:04:05", octEndStr)
	octEndStrsUnix := octEndStrs.Unix()

	novStart := this.GetString("novStart")
	//fmt.Println("11月始", novStart)
	novStartStr, _ := utils.ParseTimeStringToTime("2006-01-02", novStart)
	novStartStrUnix := novStartStr.Unix()

	novEnd := this.GetString("novEnd")

	novEndStr := novEnd + " 23:59:59"
	novEndStrs, _ := utils.ParseTimeStringToTime("2006-01-02 15:04:05", novEndStr)
	novEndStrsUnix := novEndStrs.Unix()

	decStart := this.GetString("decStart")

	decStartStr, _ := utils.ParseTimeStringToTime("2006-01-02", decStart)
	decStartStrUnix := decStartStr.Unix()

	decEnd := this.GetString("decEnd")

	decEndStr := decEnd + " 23:59:59"
	decEndStrs, _ := utils.ParseTimeStringToTime("2006-01-02 15:04:05", decEndStr)
	decEndStrsUnix := decEndStrs.Unix()

	range_type, _ := this.GetInt64("range_type")
	if range_type == 1 {
		//统计总共
		monthlist, err := service.GetMonthProjectList(orgid, lapseto, modetype, januaryStartStrUnix, januaryEndStrUnix, febStartStrStrUnix, febEndStrUnix, marchStartStrUnix, marchEndStrUnix, aprStartStrUnix, aprEndStrsUnix, mayStartStrUnix, mayEndStrsUnix, junStartStrUnix, junEndStrsUnix, julStartStrUnix, julEndStrsUnix, augStartStrUnix, augEndStrsUnix, sepStartStrUnix, sepEndStrsUnix, octStartStrUnix, octEndStrsUnix, novStartStrUnix, novEndStrsUnix, decStartStrUnix, decEndStrsUnix)
		//统计不合格
		monthNolist, err := service.GetMonthProjectListTwo(orgid, lapseto, modetype, januaryStartStrUnix, januaryEndStrUnix, febStartStrStrUnix, febEndStrUnix, marchStartStrUnix, marchEndStrUnix, aprStartStrUnix, aprEndStrsUnix, mayStartStrUnix, mayEndStrsUnix, junStartStrUnix, junEndStrsUnix, julStartStrUnix, julEndStrsUnix, augStartStrUnix, augEndStrsUnix, sepStartStrUnix, sepEndStrsUnix, octStartStrUnix, octEndStrsUnix, novStartStrUnix, novEndStrsUnix, decStartStrUnix, decEndStrsUnix)
		if err != nil {
			this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
			return
		}

		this.ServeSuccessJSON(map[string]interface{}{
			"monthlist":   monthlist,
			"monthNolist": monthNolist,
		})
	}
	if range_type == 2 {
		//统计总共
		monthlist, err := service.GetMonthProjectList(orgid, lapseto, modetype, januaryStartStrUnix, januaryEndStrUnix, febStartStrStrUnix, febEndStrUnix, marchStartStrUnix, marchEndStrUnix, aprStartStrUnix, aprEndStrsUnix, mayStartStrUnix, mayEndStrsUnix, junStartStrUnix, junEndStrsUnix, julStartStrUnix, julEndStrsUnix, augStartStrUnix, augEndStrsUnix, sepStartStrUnix, sepEndStrsUnix, octStartStrUnix, octEndStrsUnix, novStartStrUnix, novEndStrsUnix, decStartStrUnix, decEndStrsUnix)
		//统计不合格
		monthNolist, err := service.GetMonthProjectListThree(orgid, lapseto, modetype, januaryStartStrUnix, januaryEndStrUnix, febStartStrStrUnix, febEndStrUnix, marchStartStrUnix, marchEndStrUnix, aprStartStrUnix, aprEndStrsUnix, mayStartStrUnix, mayEndStrsUnix, junStartStrUnix, junEndStrsUnix, julStartStrUnix, julEndStrsUnix, augStartStrUnix, augEndStrsUnix, sepStartStrUnix, sepEndStrsUnix, octStartStrUnix, octEndStrsUnix, novStartStrUnix, novEndStrsUnix, decStartStrUnix, decEndStrsUnix)
		if err != nil {
			this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
			return
		}

		this.ServeSuccessJSON(map[string]interface{}{
			"monthlist":   monthlist,
			"monthNolist": monthNolist,
		})
	}

}

func (this *NewCommonApiController) GetAllMobileMajorInspection() {
	adminUser := this.GetMobileAdminUserInfo()
	orgid := adminUser.Org.Id
	inspection, err := service.GetMajorInspectionByOrgid(orgid)
	if len(inspection) == 0 {
		inspect, err := service.GetDefaultByOrgId(0)
		if err != nil {
			this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
			return
		}
		this.ServeSuccessJSON(map[string]interface{}{
			"inspection": inspect,
		})
	} else {
		if err != nil {
			this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
			return
		}
		this.ServeSuccessJSON(map[string]interface{}{
			"inspection": inspection,
		})
	}
}

func (this *NewCommonApiController) GetMobilePatient() {
	adminUser := this.GetMobileAdminUserInfo()
	orgid := adminUser.Org.Id
	startime := this.GetString("startime")
	endtime := this.GetString("endtime")
	startDate, parseDateErr := utils.ParseTimeStringToTime("2006-01-02", startime)
	fmt.Println("parseDateErr", parseDateErr)
	statime := startDate.Unix()
	//fmt.Println("开始时间", statime)
	//endDate, _ := utils.ParseTimeStringToTime("2006-01-02", endtime)
	//entime := endDate.Unix()
	//fmt.Println("结束日期", entime)
	decEndStr := endtime + " 23:59:59"
	decEndStrs, _ := utils.ParseTimeStringToTime("2006-01-02 15:04:05", decEndStr)
	entime := decEndStrs.Unix()
	limit, _ := this.GetInt64("limit")
	//fmt.Println("limit", limit)
	page, _ := this.GetInt64("page")
	//fmt.Println("page", page)
	patientInfo, total, err := service.GetPatientListData(orgid, statime, entime, limit, page)
	info, _ := service.GetPatientListInfo(orgid, statime, entime, limit, page)
	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}
	this.ServeSuccessJSON(map[string]interface{}{
		"patientInfo": patientInfo,
		"total":       total,
		"list":        info,
	})
}

func (this *NewCommonApiController) GetMobilePatientDetailCheck() {

	adminUser := this.GetMobileAdminUserInfo()
	orgid := adminUser.Org.Id
	id, _ := this.GetInt64("id")
	startime := this.GetString("startime")
	endtime := this.GetString("endtime")
	startDate, parseDateErr := utils.ParseTimeStringToTime("2006-01-02", startime)
	fmt.Println("parseDateErr", parseDateErr)
	statime := startDate.Unix()
	//fmt.Println("开始时间", statime)
	//endDate, _ := utils.ParseTimeStringToTime("2006-01-02", endtime)
	//entime := endDate.Unix()
	//fmt.Println("结束日期", entime)
	secondQuarterEndStr := endtime + " 23:59:59"
	secondQuarterEnds, parseDateErr := utils.ParseTimeStringToTime("2006-01-02 15:04:05", secondQuarterEndStr)
	entime := secondQuarterEnds.Unix()
	checkDetail, err := service.GetPatientDetailCheck(id, orgid, statime, entime)
	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}
	this.ServeSuccessJSON(map[string]interface{}{
		"checkDetail": checkDetail,
	})
}

func (this *NewCommonApiController) GetMobilePatientControl() {
	adminInfo := this.GetMobileAdminUserInfo()
	orgid := adminInfo.Org.Id
	lapstor, _ := this.GetInt64("lapstor")
	//fmt.Println("lapstor", lapstor)
	startime := this.GetString("startime")

	startimeStr, _ := utils.ParseTimeStringToTime("2006-01-02", startime)
	startimeStrUnix := startimeStr.Unix()

	endtime := this.GetString("endtime")

	endtimeStr := endtime + " 23:59:59"
	endtimeStrs, _ := utils.ParseTimeStringToTime("2006-01-02 15:04:05", endtimeStr)
	endtimeStrsUnix := endtimeStrs.Unix()

	page, _ := this.GetInt64("page")

	limit, _ := this.GetInt64("limit")

	patients, total, err := service.GetPatientsControl(orgid, lapstor, startimeStrUnix, endtimeStrsUnix, page, limit)

	control, err := service.GetLastPatientsControl(orgid, lapstor, startimeStrUnix, endtimeStrsUnix)
	//获取最后一次数据
	//统计传染病类型
	infectiousControl, err := service.GetInfectiousControl(orgid, lapstor, startimeStrUnix, endtimeStrsUnix)
	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}

	this.ServeSuccessJSON(map[string]interface{}{
		"patients":          patients,
		"total":             total,
		"control":           control,
		"infectiousControl": infectiousControl,
	})
}

func (this *NewCommonApiController) GetMobileCartogramlist() {
	adminInfo := this.GetMobileAdminUserInfo()
	orgid := adminInfo.Org.Id
	//lapstor, _ := this.GetInt64("lapstor")
	//fmt.Println("lapstor", lapstor)
	startime := this.GetString("startime")

	startimeStr, _ := utils.ParseTimeStringToTime("2006-01-02", startime)
	startimeStrUnix := startimeStr.Unix()

	endtime := this.GetString("endtime")

	endtimeStr := endtime + " 23:59:59"
	endtimeStrs, _ := utils.ParseTimeStringToTime("2006-01-02 15:04:05", endtimeStr)
	endtimeStrsUnix := endtimeStrs.Unix()
	fmt.Println("结束时间搓", endtimeStrsUnix)
	//统计总共
	_, total, err := service.GetTotalPatientsControl(orgid, startimeStrUnix, endtimeStrsUnix)

	_, standtotal, err := service.GetStandControl(orgid, startimeStrUnix, endtimeStrsUnix)

	_, standtotalOne, err := service.GetStandControlOne(orgid, startimeStrUnix, endtimeStrsUnix)

	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}

	this.ServeSuccessJSON(map[string]interface{}{
		"total":         total,
		"standtotal":    standtotal,
		"standtotalOne": standtotalOne,
	})
}

func (this *NewCommonApiController) GetMobileQualityControl() {
	adminInfo := this.GetMobileAdminUserInfo()
	orgid := adminInfo.Org.Id

	patientid, _ := this.GetInt64("patientid")

	startime, _ := this.GetInt64("startime")

	endtime, _ := this.GetInt64("endtime")

	itemid, _ := this.GetInt64("itemid")

	inspectdate, _ := this.GetInt64("inspectdate")
	list, err := service.GetQualityControlById(orgid, patientid, startime, endtime, itemid, inspectdate)
	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}

	this.ServeSuccessJSON(map[string]interface{}{

		"list": list,
	})
}

func (this *NewCommonApiController) GetSeachPatientsControl() {
	adminUser := this.GetMobileAdminUserInfo()
	orgid := adminUser.Org.Id

	id, _ := this.GetInt64("id")

	startime := this.GetString("startime")

	startimeStr, _ := utils.ParseTimeStringToTime("2006-01-02", startime)
	startimeStrUnix := startimeStr.Unix()

	endtime := this.GetString("endtime")

	endtimeStr := endtime + " 23:59:59"
	endtimeStrs, _ := utils.ParseTimeStringToTime("2006-01-02 15:04:05", endtimeStr)
	endtimeStrsUnix := endtimeStrs.Unix()

	control, err := service.GetLastPatientsControlTwo(orgid, id, startimeStrUnix, endtimeStrsUnix)

	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}

	this.ServeSuccessJSON(map[string]interface{}{
		"control": control,
	})
}

func (this *NewCommonApiController) GetMobileTreatlist() {
	adminUser := this.GetMobileAdminUserInfo()
	orgId := adminUser.Org.Id
	startime := this.GetString("startime")

	endtime := this.GetString("endtime")
	startDate, parseDateErr := utils.ParseTimeStringToTime("2006-01-02", startime)
	fmt.Println("parseDateErr", parseDateErr)
	statime := startDate.Unix()

	endDate, _ := utils.ParseTimeStringToTime("2006-01-02", endtime)
	entime := endDate.Unix()

	value, _ := this.GetInt64("value")

	list, err := service.GetTreatList(orgId, statime, entime, value)
	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}

	this.ServeSuccessJSON(map[string]interface{}{

		"list": list,
	})
}

func (this *NewCommonApiController) GetPatientComplianceDetail() {
	adminInfo := this.GetMobileAdminUserInfo()
	orgid := adminInfo.Org.Id

	patientid, _ := this.GetInt64("patientid")

	startime, _ := this.GetInt64("startime")

	endtime, _ := this.GetInt64("endtime")

	itemid, _ := this.GetInt64("itemid")

	list, err := service.GetPatientComplianceDetail(orgid, patientid, startime, endtime, itemid)
	if err != nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeSystemError)
		return
	}

	this.ServeSuccessJSON(map[string]interface{}{

		"list": list,
	})
}
